@@ -1,7 +1,9 @@
-package MooseX::Storage; # git description: v0.48-17-g27a5788
+package MooseX::Storage; # git description: v0.52-18-g2733271
 # ABSTRACT: A serialization framework for Moose classes
 # KEYWORDS: moose extension serial serialization class object store storage types strings
-our $VERSION = '0.49';
+
+our $VERSION = '0.53';
+
 use Moose 0.99;
 use MooseX::Storage::Meta::Attribute::DoNotSerialize;
 use String::RewritePrefix ();
@@ -117,7 +119,7 @@ MooseX::Storage - A serialization framework for Moose classes
 
 =head1 VERSION
 
-version 0.49
+version 0.53
 
 =head1 SYNOPSIS
 
@@ -168,7 +170,7 @@ to a number of different formats and styles.
 
 =head2 Levels of Serialization
 
-There are 3 levels to the serialization, each of which builds upon
+There are three levels to the serialization, each of which builds upon
 the other and each of which can be customized to the specific needs
 of your class.
 
@@ -262,14 +264,14 @@ See L<MooseX::Storage::Meta::Attribute::Trait::DoNotSerialize> for details.
 
 =head2 How we serialize
 
-There are always limits to any serialization framework, there are just
+There are always limits to any serialization framework -- there are just
 some things which are really difficult to serialize properly and some
 things which cannot be serialized at all.
 
 =head2 What can be serialized?
 
 Currently only numbers, string, ARRAY refs, HASH refs and other
-MooseX::Storage enabled objects are supported.
+MooseX::Storage-enabled objects are supported.
 
 With Array and Hash references the first level down is inspected and
 any objects found are serialized/deserialized for you. We do not do
@@ -279,7 +281,7 @@ option eventually.
 =for stopwords subtypes
 
 The specific serialize/deserialize routine is determined by the
-Moose type constraint a specific attribute has. In most cases subtypes
+L<Moose> type constraint a specific attribute has. In most cases subtypes
 of the supported types are handled correctly, and there is a facility
 for adding handlers for custom types as well. This will get documented
 eventually, but it is currently still in development.
@@ -287,7 +289,7 @@ eventually, but it is currently still in development.
 =head2 What can not be serialized?
 
 We do not support CODE references yet, but this support might be added
-in using B::Deparse or some other deep magic.
+in using L<B::Deparse> or some other deep magic.
 
 Scalar refs are not supported, mostly because there is no way to know
 if the value being referenced will be there when the object is inflated.
@@ -364,11 +366,16 @@ For the time being, please read the tests and feel free to email me
 if you have any questions. This module can also be discussed on IRC
 in the #moose channel on irc.perl.org.
 
-=head1 BUGS
+=head1 SUPPORT
 
-All complex software has bugs lurking in it, and this module is no
-exception. If you find a bug please either email me, or add the bug
-to cpan-RT.
+Bugs may be submitted through L<the RT bug tracker|https://rt.cpan.org/Public/Dist/Display.html?Name=MooseX-Storage>
+(or L<bug-MooseX-Storage@rt.cpan.org|mailto:bug-MooseX-Storage@rt.cpan.org>).
+
+There is also a mailing list available for users of this distribution, at
+L<http://lists.perl.org/list/moose.html>.
+
+There is also an irc channel available for users of this distribution, at
+L<C<#moose> on C<irc.perl.org>|irc://irc.perl.org/#moose>.
 
 =head1 AUTHORS
 
@@ -388,16 +395,9 @@ Stevan Little <stevan.little@iinteractive.com>
 
 =back
 
-=head1 COPYRIGHT AND LICENSE
-
-This software is copyright (c) 2007 by Infinity Interactive, Inc..
-
-This is free software; you can redistribute it and/or modify it under
-the same terms as the Perl 5 programming language system itself.
-
 =head1 CONTRIBUTORS
 
-=for stopwords Karen Etheridge Tomas Doran Ricardo Signes Chris Prather Jos Boumans Shawn M Moore Jonathan Yu Dagfinn Ilmari Mannsåker Dmitry Latin Cory Watson Robert Boone sillitoe Dan Brook David Golden Steinbrunner Florian Ragwitz Jason Pope Johannes Plunien Rockway
+=for stopwords Karen Etheridge Tomas Doran Ricardo Signes Chris Prather Jos Boumans Shawn M Moore Jonathan Yu Dmitry Latin Robert Boone Dagfinn Ilmari Mannsåker Cory Watson sillitoe Dan Brook David Golden Steinbrunner Florian Ragwitz Graham Knop Jason Pope Johannes Plunien Rockway Yanick Champoux
 
 =over 4
 
@@ -431,19 +431,19 @@ Jonathan Yu <frequency@cpan.org>
 
 =item *
 
-Dagfinn Ilmari Mannsåker <ilmari@ilmari.org>
-
-=item *
-
 Dmitry Latin <dim0xff@gmail.com>
 
 =item *
 
-Cory Watson <gphat@Crankwizzah.local>
+Robert Boone <robo4288@gmail.com>
 
 =item *
 
-Robert Boone <robo4288@gmail.com>
+Dagfinn Ilmari Mannsåker <ilmari@ilmari.org>
+
+=item *
+
+Cory Watson <gphat@Crankwizzah.local>
 
 =item *
 
@@ -467,6 +467,10 @@ Florian Ragwitz <rafl@debian.org>
 
 =item *
 
+Graham Knop <haarg@haarg.org>
+
+=item *
+
 Jason Pope <cowholio4@gmail.com>
 
 =item *
@@ -477,6 +481,17 @@ Johannes Plunien <plu@pqpq.de>
 
 Jonathan Rockway <jon@jrock.us>
 
+=item *
+
+Yanick Champoux <yanick@babyl.dyndns.org>
+
 =back
 
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2007 by Infinity Interactive, Inc.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =cut
