@@ -1,6 +1,8 @@
 package MooseX::Storage::Basic;
 # ABSTRACT: The simplest level of serialization
-our $VERSION = '0.49';
+
+our $VERSION = '0.53';
+
 use Moose::Role;
 use MooseX::Storage::Engine;
 use String::RewritePrefix;
@@ -54,8 +56,6 @@ sub _storage_construct_instance {
     $class->new( %$args, %i );
 }
 
-no Moose::Role;
-
 1;
 
 __END__
@@ -70,7 +70,7 @@ MooseX::Storage::Basic - The simplest level of serialization
 
 =head1 VERSION
 
-version 0.49
+version 0.53
 
 =head1 SYNOPSIS
 
@@ -124,19 +124,16 @@ the class' C<new> function, or override ones from the serialized data.
 
 =back
 
-=head2 Introspection
+=head1 SUPPORT
 
-=over 4
+Bugs may be submitted through L<the RT bug tracker|https://rt.cpan.org/Public/Dist/Display.html?Name=MooseX-Storage>
+(or L<bug-MooseX-Storage@rt.cpan.org|mailto:bug-MooseX-Storage@rt.cpan.org>).
 
-=item B<meta>
+There is also a mailing list available for users of this distribution, at
+L<http://lists.perl.org/list/moose.html>.
 
-=back
-
-=head1 BUGS
-
-All complex software has bugs lurking in it, and this module is no
-exception. If you find a bug please either email me, or add the bug
-to cpan-RT.
+There is also an irc channel available for users of this distribution, at
+L<C<#moose> on C<irc.perl.org>|irc://irc.perl.org/#moose>.
 
 =head1 AUTHORS
 
@@ -158,7 +155,7 @@ Stevan Little <stevan.little@iinteractive.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2007 by Infinity Interactive, Inc..
+This software is copyright (c) 2007 by Infinity Interactive, Inc.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
