@@ -1,6 +1,8 @@
 package MooseX::Storage::Deferred;
 # ABSTRACT: A role for indecisive programmers
-our $VERSION = '0.49';
+
+our $VERSION = '0.53';
+
 use Moose::Role;
 with 'MooseX::Storage::Basic';
 use Carp 'confess';
@@ -57,8 +59,6 @@ sub store {
     $self->$code($filename, $type, @args);
 }
 
-no Moose::Role;
-
 1;
 
 __END__
@@ -73,7 +73,7 @@ MooseX::Storage::Deferred - A role for indecisive programmers
 
 =head1 VERSION
 
-version 0.49
+version 0.53
 
 =head1 SYNOPSIS
 
@@ -162,19 +162,16 @@ and I will see what I can do.
 
 =back
 
-=head2 Introspection
+=head1 SUPPORT
 
-=over 4
+Bugs may be submitted through L<the RT bug tracker|https://rt.cpan.org/Public/Dist/Display.html?Name=MooseX-Storage>
+(or L<bug-MooseX-Storage@rt.cpan.org|mailto:bug-MooseX-Storage@rt.cpan.org>).
 
-=item B<meta>
+There is also a mailing list available for users of this distribution, at
+L<http://lists.perl.org/list/moose.html>.
 
-=back
-
-=head1 BUGS
-
-All complex software has bugs lurking in it, and this module is no
-exception. If you find a bug please either email me, or add the bug
-to cpan-RT.
+There is also an irc channel available for users of this distribution, at
+L<C<#moose> on C<irc.perl.org>|irc://irc.perl.org/#moose>.
 
 =head1 AUTHORS
 
@@ -196,7 +193,7 @@ Stevan Little <stevan.little@iinteractive.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2007 by Infinity Interactive, Inc..
+This software is copyright (c) 2007 by Infinity Interactive, Inc.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
