@@ -1,6 +1,8 @@
 package MooseX::Storage::Engine;
 # ABSTRACT: The meta-engine to handle collapsing and expanding objects
-our $VERSION = '0.49';
+
+our $VERSION = '0.53';
+
 use Moose;
 use Scalar::Util qw(refaddr blessed);
 use Carp 'confess';
@@ -111,12 +113,8 @@ sub expand_attribute_value {
     return $value;
 }
 
-# NOTE:
-# possibly these two methods will
-# be used by a cycle supporting
-# engine. However, I am not sure
-# if I can make a cycle one work
-# anyway.
+# NOTE: possibly these two methods will be used by a cycle supporting engine.
+# However, I am not sure if I can make a cycle one work anyway.
 
 sub check_for_cycle_in_collapse {
     my ($self, $attr, $value) = @_;
@@ -211,8 +209,7 @@ my %OBJECT_HANDLERS = (
 );
 
 
-my %TYPES;
-%TYPES = (
+my %TYPES = (
     # NOTE:
     # we need to make sure that we properly numify the numbers
     # before and after them being futzed with, because some of
@@ -224,32 +221,28 @@ my %TYPES;
     'Value'    => { expand => sub { shift }, collapse => sub { shift } },
     'Bool'     => { expand => sub { shift }, collapse => sub { shift } },
     # These are the trickier ones, (see notes)
+    # NOTE: Because we are nice guys, we will check your ArrayRef and/or
+    # HashRef one level down and inflate any objects we find.  But this is
+    # where it ends, it is too expensive to try and do this any more
+    # recursively, when it is probably not necessary in most of the use cases.
+    # However, if you need more than this, subtype and add a custom handler.
     'ArrayRef' => {
         expand => sub {
             my ( $array, @args ) = @_;
             foreach my $i (0 .. $#{$array}) {
-                if (ref($array->[$i]) eq 'HASH') {
-                    $array->[$i] = exists($array->[$i]{$CLASS_MARKER})
-                        ? $OBJECT_HANDLERS{expand}->($array->[$i], @args)
-                        : $TYPES{HashRef}{expand}->($array->[$i], @args);
-                }
-                elsif (ref($array->[$i]) eq 'ARRAY') {
-                    $array->[$i] = $TYPES{ArrayRef}{expand}->($array->[$i], @args);
-                }
+                next unless ref($array->[$i]) eq 'HASH'
+                         && exists $array->[$i]->{$CLASS_MARKER};
+                $array->[$i] = $OBJECT_HANDLERS{expand}->($array->[$i], @args);
             }
             $array;
         },
         collapse => sub {
             my ( $array, @args ) = @_;
-            # NOTE:
-            # we need to make a copy because
-            # otherwise it will affect the
-            # other real version.
+            # NOTE: we need to make a copy because otherwise it will affect
+            # the other real version.
             [ map {
                 blessed($_)
                     ? $OBJECT_HANDLERS{collapse}->($_, @args)
-                    : $TYPES{ref($_)}
-                    ? $TYPES{ref($_)}->{collapse}->($_, @args)
                     : $_
             } @$array ]
         }
@@ -258,50 +251,32 @@ my %TYPES;
         expand   => sub {
             my ( $hash, @args ) = @_;
             foreach my $k (keys %$hash) {
-                if (ref($hash->{$k}) eq 'HASH' ) {
-                    $hash->{$k} = exists($hash->{$k}->{$CLASS_MARKER})
-                        ? $OBJECT_HANDLERS{expand}->($hash->{$k}, @args)
-                        : $TYPES{HashRef}{expand}->($hash->{$k}, @args);
-                }
-                elsif (ref($hash->{$k}) eq 'ARRAY') {
-                    $hash->{$k} = $TYPES{ArrayRef}{expand}->($hash->{$k}, @args);
-                }
+                next unless ref($hash->{$k}) eq 'HASH'
+                         && exists $hash->{$k}->{$CLASS_MARKER};
+                $hash->{$k} = $OBJECT_HANDLERS{expand}->($hash->{$k}, @args);
             }
             $hash;
         },
         collapse => sub {
             my ( $hash, @args ) = @_;
-            # NOTE:
-            # we need to make a copy because
-            # otherwise it will affect the
-            # other real version.
+            # NOTE: we need to make a copy because otherwise it will affect
+            # the other real version.
             +{ map {
                 blessed($hash->{$_})
                     ? ($_ => $OBJECT_HANDLERS{collapse}->($hash->{$_}, @args))
-                    : $TYPES{ref($hash->{$_})}
-                    ? ($_ => $TYPES{ref($hash->{$_})}{collapse}->($hash->{$_}, @args))
                     : ($_ => $hash->{$_})
             } keys %$hash }
         }
     },
     'Object'   => \%OBJECT_HANDLERS,
-    # NOTE:
-    # The sanity of enabling this feature by
-    # default is very questionable.
-    # - SL
+    # NOTE: The sanity of enabling this feature by default is very
+    # questionable.  - SL
     #'CodeRef' => {
     #    expand   => sub {}, # use eval ...
     #    collapse => sub {}, # use B::Deparse ...
     #}
 );
 
-%TYPES = (
-    %TYPES,
-    'HASH'  => $TYPES{HashRef},
-    'ARRAY' => $TYPES{ArrayRef},
-);
-
-
 sub add_custom_type_handler {
     my ($self, $type_name, %handlers) = @_;
     (exists $handlers{expand} && exists $handlers{collapse})
@@ -317,36 +292,38 @@ sub remove_custom_type_handler {
 sub find_type_handler {
     my ($self, $type_constraint, $value) = @_;
 
-    # check if the type is a Maybe and
-    # if its parent is not parameterized.
-    # If both is true recurse this method
-    # using ->type_parameter.
-    return $self->find_type_handler($type_constraint->type_parameter, $value)
-        if ($type_constraint->parent && $type_constraint->parent eq 'Maybe'
-          and not $type_constraint->parent->can('type_parameter'));
+    # this should handle most type usages since they they are usually just the
+    # standard set of built-ins -- but we should also respect any custom type
+    # handlers that the user may have defined
+    return $TYPES{$type_constraint->name}
+        if exists $TYPES{$type_constraint->name};
+
+    # check if the type is a Maybe and if its parent is not parameterized.  If
+    # both is true recurse this method using ->type_parameter.
+    if (my $parent = $type_constraint->parent) {
+        return $self->find_type_handler($type_constraint->type_parameter, $value)
+            if $parent eq 'Maybe' and not $parent->can('type_parameter');
+
+        # also account for the additional level added by MooseX::Types's use of maybe_type
+        if ($parent->isa('Moose::Meta::TypeConstraint::Parameterized')) {
+            my $parameter = $parent->parameterized_from;
+            return $self->find_type_handler($parent->type_parameter, $value)
+                if $parameter eq 'Maybe' and not $parameter->can('type_parameter');
+        }
+    }
 
     # find_type_for is a method of a union type.  If we can call that method
-    # then we are dealign with a union and we need to ascertain which of
+    # then we are dealing with a union and we need to ascertain which of
     # the union's types we need to use for the value we are serializing.
     if($type_constraint->can('find_type_for')) {
         my $tc = $type_constraint->find_type_for($value);
         return $self->find_type_handler($tc, $value) if defined($tc);
     }
 
-    # this should handle most type usages
-    # since they they are usually just
-    # the standard set of built-ins
-    return $TYPES{$type_constraint->name}
-        if exists $TYPES{$type_constraint->name};
-
-    # the next possibility is they are
-    # a subtype of the built-in types,
-    # in which case this will DWIM in
-    # most cases. It is probably not
-    # 100% ideal though, but until I
-    # come up with a decent test case
-    # it will do for now.  We need to
-    # check more-specific types first.
+    # the next possibility is they are a subtype of the built-in types, in
+    # which case this will DWIM in most cases. It is probably not 100% ideal
+    # though, but until I come up with a decent test case it will do for now.
+    # We need to check more-specific types first.
     my %seen;
     my @fallback = grep { !$seen{$_}++ } qw/Int Num Str Value/, keys %TYPES;
     foreach my $type ( @fallback ) {
@@ -354,22 +331,14 @@ sub find_type_handler {
             if $type_constraint->is_subtype_of($type);
     }
 
-    # NOTE:
-    # the reason the above will work has to
-    # do with the fact that custom subtypes
-    # are mostly used for validation of
-    # the guts of a type, and not for some
-    # weird structural thing which would
-    # need to be accomidated by the serializer.
-    # Of course, mst or phaylon will probably
-    # do something to throw this assumption
-    # totally out the door ;)
-    # - SL
+    # NOTE: the reason the above will work has to do with the fact that custom
+    # subtypes are mostly used for validation of the guts of a type, and not
+    # for some weird structural thing which would need to be accomodated by
+    # the serializer.  Of course, mst or phaylon will probably do something to
+    # throw this assumption totally out the door ;) - SL
 
-    # NOTE:
-    # if this method hasnt returned by now
-    # then we have no been able to find a
-    # type constraint handler to match
+    # NOTE: if this method hasn't returned by now then we have not been able
+    # to find a type constraint handler to match
     confess "Cannot handle type constraint (" . $type_constraint->name . ")";
 }
 
@@ -378,8 +347,6 @@ sub find_type_handler_for {
     $TYPES{$type_handler_name}
 }
 
-no Moose::Role;
-
 1;
 
 __END__
@@ -394,13 +361,13 @@ MooseX::Storage::Engine - The meta-engine to handle collapsing and expanding obj
 
 =head1 VERSION
 
-version 0.49
+version 0.53
 
 =head1 DESCRIPTION
 
 There really aren't any major user serviceable parts here. However the typical
 use case is adding new non-Moose classes to the type registry for
-serialization. Here is an example of this for DateTime objects. This
+serialization. Here is an example of this for L<DateTime> objects. This
 assumes a C<DateTime> type has been registered.
 
     MooseX::Storage::Engine->add_custom_type_handler(
@@ -470,19 +437,16 @@ assumes a C<DateTime> type has been registered.
 
 =back
 
-=head2 Introspection
+=head1 SUPPORT
 
-=over 4
+Bugs may be submitted through L<the RT bug tracker|https://rt.cpan.org/Public/Dist/Display.html?Name=MooseX-Storage>
+(or L<bug-MooseX-Storage@rt.cpan.org|mailto:bug-MooseX-Storage@rt.cpan.org>).
 
-=item B<meta>
+There is also a mailing list available for users of this distribution, at
+L<http://lists.perl.org/list/moose.html>.
 
-=back
-
-=head1 BUGS
-
-All complex software has bugs lurking in it, and this module is no
-exception. If you find a bug please either email me, or add the bug
-to cpan-RT.
+There is also an irc channel available for users of this distribution, at
+L<C<#moose> on C<irc.perl.org>|irc://irc.perl.org/#moose>.
 
 =head1 AUTHORS
 
@@ -504,7 +468,7 @@ Stevan Little <stevan.little@iinteractive.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2007 by Infinity Interactive, Inc..
+This software is copyright (c) 2007 by Infinity Interactive, Inc.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
