@@ -1,7 +1,7 @@
 package MooseX::Storage::Format::JSON;
 # ABSTRACT: A JSON serialization role
 
-our $VERSION = '0.50';
+our $VERSION = '0.53';
 
 use Moose::Role;
 use JSON::MaybeXS 1.001000;
@@ -31,8 +31,6 @@ sub freeze {
     return $json;
 }
 
-no Moose::Role;
-
 1;
 
 __END__
@@ -47,7 +45,7 @@ MooseX::Storage::Format::JSON - A JSON serialization role
 
 =head1 VERSION
 
-version 0.50
+version 0.53
 
 =head1 SYNOPSIS
 
@@ -84,19 +82,16 @@ version 0.50
 
 =back
 
-=head2 Introspection
+=head1 SUPPORT
 
-=over 4
+Bugs may be submitted through L<the RT bug tracker|https://rt.cpan.org/Public/Dist/Display.html?Name=MooseX-Storage>
+(or L<bug-MooseX-Storage@rt.cpan.org|mailto:bug-MooseX-Storage@rt.cpan.org>).
 
-=item B<meta>
+There is also a mailing list available for users of this distribution, at
+L<http://lists.perl.org/list/moose.html>.
 
-=back
-
-=head1 BUGS
-
-All complex software has bugs lurking in it, and this module is no
-exception. If you find a bug please or add the bug to cpan-RT
-at L<https://rt.cpan.org/Dist/Display.html?Queue=MooseX-Storage>.
+There is also an irc channel available for users of this distribution, at
+L<C<#moose> on C<irc.perl.org>|irc://irc.perl.org/#moose>.
 
 =head1 AUTHORS
 
@@ -118,7 +113,7 @@ Stevan Little <stevan.little@iinteractive.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2007 by Infinity Interactive, Inc..
+This software is copyright (c) 2007 by Infinity Interactive, Inc.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
