@@ -1,6 +1,8 @@
 package MooseX::Storage::Traits::OnlyWhenBuilt;
 # ABSTRACT: A custom trait to bypass serialization
-our $VERSION = '0.49';
+
+our $VERSION = '0.53';
+
 use Moose::Role;
 use namespace::autoclean;
 
@@ -21,8 +23,6 @@ around 'unpack' => sub {
     $self->$orig($data, %args);
 };
 
-no Moose::Role;
-
 1;
 
 __END__
@@ -37,7 +37,7 @@ MooseX::Storage::Traits::OnlyWhenBuilt - A custom trait to bypass serialization
 
 =head1 VERSION
 
-version 0.49
+version 0.53
 
 =head1 SYNOPSIS
 
@@ -48,7 +48,7 @@ version 0.49
         with Storage( traits => [qw|OnlyWhenBuilt|] );
 
         has 'x' => (is => 'rw', lazy_build => 1 );
-        has 'y' => (is => 'rw', lazy_build => 1 );
+        has 'y' => (is => 'rw', predicate => '_has_y' );
         has 'z' => (is => 'rw', builder => '_build_z' );
 
         sub _build_x { 3 }
@@ -75,21 +75,16 @@ This avoids any potentially expensive computations.
 
 See the SYNOPSIS for a nice example that can be easily cargo-culted.
 
-=head1 METHODS
+=head1 SUPPORT
 
-=head2 Introspection
+Bugs may be submitted through L<the RT bug tracker|https://rt.cpan.org/Public/Dist/Display.html?Name=MooseX-Storage>
+(or L<bug-MooseX-Storage@rt.cpan.org|mailto:bug-MooseX-Storage@rt.cpan.org>).
 
-=over 4
+There is also a mailing list available for users of this distribution, at
+L<http://lists.perl.org/list/moose.html>.
 
-=item B<meta>
-
-=back
-
-=head1 BUGS
-
-All complex software has bugs lurking in it, and this module is no
-exception. If you find a bug please either email me, or add the bug
-to cpan-RT.
+There is also an irc channel available for users of this distribution, at
+L<C<#moose> on C<irc.perl.org>|irc://irc.perl.org/#moose>.
 
 =head1 AUTHORS
 
@@ -111,7 +106,7 @@ Stevan Little <stevan.little@iinteractive.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2007 by Infinity Interactive, Inc..
+This software is copyright (c) 2007 by Infinity Interactive, Inc.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
